<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Quivers\Integration\Controller\Sales\Adminhtml\Order;

class Unhold extends \Magento\Sales\Controller\Adminhtml\Order
{

    protected $scopeConfig;
    protected $curlClient;

    const XML_QUIVERS_SANDBOX = 'quivers/parameters/quivers_sanndbox';
    const XML_QUIVERS_API_KEY = 'quivers/parameters/quivers_api_key';
    const XML_QUIVERS_MERCHANT_REF_ID = 'quivers/parameters/merchant_ref_id';


    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Magento_Sales::unhold';

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Registry $coreRegistry,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Magento\Framework\Translate\InlineInterface $translateInline,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Framework\View\Result\LayoutFactory $resultLayoutFactory,
        \Magento\Framework\Controller\Result\RawFactory $resultRawFactory,
        \Magento\Sales\Model\Service\OrderService $orderManagement,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Magento\Framework\Logger\Monolog $logger,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\HTTP\Client\Curl $curl
    ) {
        parent::__construct($context, $coreRegistry, $fileFactory, $translateInline,
                    $resultPageFactory, $resultJsonFactory, $resultLayoutFactory,
                    $resultRawFactory, $orderManagement, $orderRepository, $logger);
        $this->curlClient = $curl;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * Unhold order
     *
     * @return \Magento\Backend\Model\View\Result\Redirect
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();
        
        $order = $this->_initOrder();
        if ($order) {
            $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
            $quiversSandbox = $this->scopeConfig->getValue(self::XML_QUIVERS_SANDBOX, $storeScope);
            $quiversAPIKey = $this->scopeConfig->getValue(self::XML_QUIVERS_API_KEY, $storeScope);
            $merchantREFId = $this->scopeConfig->getValue(self::XML_QUIVERS_MERCHANT_REF_ID, $storeScope);

            if (!ValidateOrderAction::validateOrderAction(
                    $order->getId(), $quiversSandbox, $quiversAPIKey, $merchantREFId, $this->curlClient)) {
                $this->messageManager->addError(__('Can\'t unhold order.'));
                $resultRedirect->setPath('sales/order/view', ['order_id' => $order->getId()]);
                return $resultRedirect;
            }

            try {
                if (!$order->canUnhold()) {
                    throw new \Magento\Framework\Exception\LocalizedException(__('Can\'t unhold order.'));
                }
                $this->orderManagement->unhold($order->getEntityId());
                $this->messageManager->addSuccess(__('You released the order from holding status.'));
            } catch (\Magento\Framework\Exception\LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addError(__('The order was not on hold.'));
            }
            $resultRedirect->setPath('sales/order/view', ['order_id' => $order->getId()]);
            return $resultRedirect;
        }

        $resultRedirect->setPath('sales/*/');
        return $resultRedirect;

    }
}
